@@ -324,8 +324,11 @@ static void NotifyInit (int ok)
 		    write (fd, "LOW\n", 4);
 		else
                     write (fd, "FAIL\n", 5);
-		
                break;
+
+	    default:
+		write (fd, "OK\n", 3);
+	        break;
             }
         close (fd);
         }
@@ -485,6 +488,7 @@ int main (int argc, char *argv [])
                     {
                     Mode_Test = TRUE;
                     Mode_NoMaster = TRUE;
+                    LastValidStatus = S_NOCHANGE;
                     }
                 break;
                                     
